Primitive

Trait Primitive 

pub trait Primitive {
    type RenderPacket: RenderResource<Data = Self> + Send + Sync + 'static;
}
The Primitive is the basic renderable object in Ranim.

The Primitive itself is simply the data of the object. A Primitive can generate a corresponding Primitive::RenderPacket, which implements RenderResource:

Required Associated Types

type RenderPacket: RenderResource<Data = Self> + Send + Sync + 'static

The RenderInstance

Implementors