pub trait Primitive {
type RenderPacket: RenderResource<Data = Self> + Send + Sync + 'static;
}Expand description
The Primitive is the basic renderable object in Ranim.
The Primitive itself is simply the data of the object.
A Primitive can generate a corresponding Primitive::RenderPacket,
which implements RenderResource:
RenderResource: A trait about init or update itself withRenderResource::Data.
Required Associated Types
Sourcetype RenderPacket: RenderResource<Data = Self> + Send + Sync + 'static
type RenderPacket: RenderResource<Data = Self> + Send + Sync + 'static
The RenderInstance